@@ -150,20 +150,28 @@ get_header_n_value.data.frame <- function(x, ...) {
 #' @noRd
 get_denom_total <- function(.data, denoms_by, denoms_df, denoms_distinct_df, total_extract = "n") {
 
-  # Filter denoms dataset
-  filter_logic <- map(denoms_by, function(x) {
-    expr(!!sym(as_name(x)) == !!unique(.data[, as_name(x)])[[1]])
-  })
-
   if(total_extract == "n") {
+    # Filter denoms dataset
+    vars_in_denoms <- denoms_by[map_lgl(denoms_by, ~ as_name(.) %in% names(denoms_df))]
+    filter_logic <- map(vars_in_denoms, function(x) {
+      expr(!!sym(as_name(x)) == !!unique(.data[, as_name(x)])[[1]])
+    })
+
     sums <-  denoms_df %>%
       filter(!!!filter_logic) %>%
-      group_by(!!!denoms_by) %>%
+      group_by(!!!vars_in_denoms) %>%
       extract("n")
+
   } else {
+    # Filter denoms dataset
+    vars_in_denoms <- denoms_by[map_lgl(denoms_by, ~ as_name(.) %in% names(denoms_distinct_df))]
+    filter_logic <- map(vars_in_denoms, function(x) {
+      expr(!!sym(as_name(x)) == !!unique(.data[, as_name(x)])[[1]])
+    })
+
     sums <- denoms_distinct_df %>%
       filter(!!!filter_logic) %>%
-      group_by(!!!denoms_by) %>%
+      group_by(!!!vars_in_denoms) %>%
       extract("distinct_n")
   }
 
