@@ -6,9 +6,9 @@ test_that("A group_count layer can be ordered properly with factors", {
       group_count(cyl)
     )
   b_t <- build(t)
-  expect_equivalent(b_t[, 1], tibble(row_label1 = as.character(c(4, 6, 8))))
-  expect_equivalent(b_t[, 5], tibble(ord_layer_index = as.integer(c(1, 1, 1))))
-  expect_equivalent(b_t[, 6], tibble(ord_layer_1 = as.numeric(c(1, 2, 3))))
+  expect_equal(b_t[, 1], tibble(row_label1 = as.character(c(4, 6, 8))), ignore_attr = TRUE)
+  expect_equal(b_t[, 5], tibble(ord_layer_index = as.integer(c(1, 1, 1))), ignore_attr = TRUE)
+  expect_equal(b_t[, 6], tibble(ord_layer_1 = as.numeric(c(1, 2, 3))), ignore_attr = TRUE)
 
   mtcars$cyl <- factor(mtcars$cyl, c(6, 8, 4))
   t2 <- tplyr_table(mtcars, gear) %>%
@@ -16,9 +16,9 @@ test_that("A group_count layer can be ordered properly with factors", {
       group_count(cyl)
     )
   b_t2 <- build(t2)
-  expect_equivalent(b_t2[, 1], tibble(row_label1 = as.character(c(6, 8, 4))))
-  expect_equivalent(b_t2[, 5], tibble(ord_layer_index = as.integer(c(1, 1, 1))))
-  expect_equivalent(b_t2[, 6], tibble(ord_layer_1 = as.numeric(c(1, 2, 3))))
+  expect_equal(b_t2[, 1], tibble(row_label1 = as.character(c(6, 8, 4))), ignore_attr = TRUE)
+  expect_equal(b_t2[, 5], tibble(ord_layer_index = as.integer(c(1, 1, 1))), ignore_attr = TRUE)
+  expect_equal(b_t2[, 6], tibble(ord_layer_1 = as.numeric(c(1, 2, 3))), ignore_attr = TRUE)
 
   t3 <- tplyr_table(mtcars, gear) %>%
     add_layer(
@@ -26,13 +26,13 @@ test_that("A group_count layer can be ordered properly with factors", {
     )
   b_t3 <- build(t3) %>%
     arrange(ord_layer_1, ord_layer_2, ord_layer_3)
-  expect_equivalent(b_t3[, 1], tibble(row_label1 = as.character(rep(c(0, 1), each = 6))))
-  expect_equivalent(b_t3[, 2], tibble(row_label2 = as.character(rep(c(0, 0, 0, 1, 1, 1), 2))))
-  expect_equivalent(b_t3[, 3], tibble(row_label3 = as.character(rep(c(6, 8, 4), 4))))
-  expect_equivalent(b_t3[, 7], tibble(ord_layer_index = as.integer(rep(1, 12))))
-  expect_equivalent(b_t3[, 8], tibble(ord_layer_1 = as.integer(rep(c(1, 2), each = 6))))
-  expect_equivalent(b_t3[, 9], tibble(ord_layer_2 = as.integer(rep(c(1, 1, 1, 2, 2, 2), 2))))
-  expect_equivalent(b_t3[, 10], tibble(ord_layer_3 = as.numeric(rep(c(1, 2, 3), 4))))
+  expect_equal(b_t3[, 1], tibble(row_label1 = as.character(rep(c(0, 1), each = 6))), ignore_attr = TRUE)
+  expect_equal(b_t3[, 2], tibble(row_label2 = as.character(rep(c(0, 0, 0, 1, 1, 1), 2))), ignore_attr = TRUE)
+  expect_equal(b_t3[, 3], tibble(row_label3 = as.character(rep(c(6, 8, 4), 4))), ignore_attr = TRUE)
+  expect_equal(b_t3[, 7], tibble(ord_layer_index = as.integer(rep(1, 12))), ignore_attr = TRUE)
+  expect_equal(b_t3[, 8], tibble(ord_layer_1 = as.integer(rep(c(1, 2), each = 6))), ignore_attr = TRUE)
+  expect_equal(b_t3[, 9], tibble(ord_layer_2 = as.integer(rep(c(1, 1, 1, 2, 2, 2), 2))), ignore_attr = TRUE)
+  expect_equal(b_t3[, 10], tibble(ord_layer_3 = as.numeric(rep(c(1, 2, 3), 4))), ignore_attr = TRUE)
 })
 
 test_that("A group_count layer can be ordered properly by counts", {
@@ -43,16 +43,16 @@ test_that("A group_count layer can be ordered properly by counts", {
     )
   b_t1 <- build(t1) %>%
     arrange(ord_layer_1, ord_layer_2, ord_layer_2)
-  expect_equivalent(b_t1[, 1], tibble(row_label1 = as.character(rep(c(0, 1), each = 6))))
-  expect_equivalent(b_t1[, 2], tibble(row_label2 = as.character(rep(c(0, 0, 0, 1, 1, 1), 2))))
-  expect_equivalent(b_t1[, 3], tibble(row_label3 = as.character(rep(c(4, 6, 8), 4))))
-  expect_equivalent(b_t1[, 7], tibble(ord_layer_index = as.integer(rep(1, 12))))
-  expect_equivalent(b_t1[, 8], tibble(ord_layer_1 = as.integer(rep(c(1, 2), each = 6))))
-  expect_equivalent(b_t1[, 9], tibble(ord_layer_2 = as.integer(rep(c(1, 1, 1, 2, 2, 2), 2))))
-  expect_equivalent(b_t1[, 10], tibble(ord_layer_3 = as.numeric(c(0, 0, 0,
+  expect_equal(b_t1[, 1], tibble(row_label1 = as.character(rep(c(0, 1), each = 6))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 2], tibble(row_label2 = as.character(rep(c(0, 0, 0, 1, 1, 1), 2))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 3], tibble(row_label3 = as.character(rep(c(4, 6, 8), 4))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 7], tibble(ord_layer_index = as.integer(rep(1, 12))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 8], tibble(ord_layer_1 = as.integer(rep(c(1, 2), each = 6))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 9], tibble(ord_layer_2 = as.integer(rep(c(1, 1, 1, 2, 2, 2), 2))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 10], tibble(ord_layer_3 = as.numeric(c(0, 0, 0,
                                                              2, 2, 0,
                                                              0, 2, 0,
-                                                             6, 0, 0))))
+                                                             6, 0, 0))), ignore_attr = TRUE)
 
   t2 <- tplyr_table(mtcars, gear) %>%
     add_layer(
@@ -62,16 +62,16 @@ test_that("A group_count layer can be ordered properly by counts", {
     )
   b_t2 <- build(t2) %>%
     arrange(ord_layer_1, ord_layer_2, ord_layer_3)
-  expect_equivalent(b_t2[, 1], tibble(row_label1 = as.character(rep(c(0, 1), each = 6))))
-  expect_equivalent(b_t2[, 2], tibble(row_label2 = as.character(rep(c(0, 0, 0, 1, 1, 1), 2))))
-  expect_equivalent(b_t2[, 3], tibble(row_label3 = as.character(c(4, 6, 8, 8, 4, 6, 4, 6, 8, 4, 6, 8))))
-  expect_equivalent(b_t2[, 7], tibble(ord_layer_index = as.integer(rep(1, 12))))
-  expect_equivalent(b_t2[, 8], tibble(ord_layer_1 = as.integer(rep(c(1, 2), each = 6))))
-  expect_equivalent(b_t2[, 9], tibble(ord_layer_2 = as.integer(rep(c(1, 1, 1, 2, 2, 2), 2))))
-  expect_equivalent(b_t2[, 10], tibble(ord_layer_3 = as.numeric(c(0, 0, 12,
+  expect_equal(b_t2[, 1], tibble(row_label1 = as.character(rep(c(0, 1), each = 6))), ignore_attr = TRUE)
+  expect_equal(b_t2[, 2], tibble(row_label2 = as.character(rep(c(0, 0, 0, 1, 1, 1), 2))), ignore_attr = TRUE)
+  expect_equal(b_t2[, 3], tibble(row_label3 = as.character(c(4, 6, 8, 8, 4, 6, 4, 6, 8, 4, 6, 8))), ignore_attr = TRUE)
+  expect_equal(b_t2[, 7], tibble(ord_layer_index = as.integer(rep(1, 12))), ignore_attr = TRUE)
+  expect_equal(b_t2[, 8], tibble(ord_layer_1 = as.integer(rep(c(1, 2), each = 6))), ignore_attr = TRUE)
+  expect_equal(b_t2[, 9], tibble(ord_layer_2 = as.integer(rep(c(1, 1, 1, 2, 2, 2), 2))), ignore_attr = TRUE)
+  expect_equal(b_t2[, 10], tibble(ord_layer_3 = as.numeric(c(0, 0, 12,
                                                              0, 1, 2,
                                                              0, 0, 0,
-                                                             0, 0, 0))))
+                                                             0, 0, 0))), ignore_attr = TRUE)
 
 })
 
@@ -85,13 +85,13 @@ test_that("A group_count layer can be ordered properly by a VARN", {
   b_t1 <- build(t1) %>%
     arrange(ord_layer_1, ord_layer_2)
 
-  expect_equivalent(b_t1[, 1], tibble(row_label1 = as.character(rep(c(0, 1), each = 6))))
-  expect_equivalent(b_t1[, 2], tibble(row_label2 = as.character(rep(c(0, 0, 0, 1, 1, 1), 2))))
-  expect_equivalent(b_t1[, 3], tibble(row_label3 = as.character(rep(c(4, 6, 8), 4))))
-  expect_equivalent(b_t1[, 7], tibble(ord_layer_index = as.integer(rep(1, 12))))
-  expect_equivalent(b_t1[, 8], tibble(ord_layer_1 = as.integer(rep(c(1, 2), each = 6))))
-  expect_equivalent(b_t1[, 9], tibble(ord_layer_2 = as.integer(rep(c(1, 1, 1, 2, 2, 2), 2))))
-  expect_equivalent(b_t1[, 10], tibble(ord_layer_3 = as.numeric(rep(c(4, 6, 8), 4))))
+  expect_equal(b_t1[, 1], tibble(row_label1 = as.character(rep(c(0, 1), each = 6))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 2], tibble(row_label2 = as.character(rep(c(0, 0, 0, 1, 1, 1), 2))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 3], tibble(row_label3 = as.character(rep(c(4, 6, 8), 4))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 7], tibble(ord_layer_index = as.integer(rep(1, 12))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 8], tibble(ord_layer_1 = as.integer(rep(c(1, 2), each = 6))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 9], tibble(ord_layer_2 = as.integer(rep(c(1, 1, 1, 2, 2, 2), 2))), ignore_attr = TRUE)
+  expect_equal(b_t1[, 10], tibble(ord_layer_3 = as.numeric(rep(c(4, 6, 8), 4))), ignore_attr = TRUE)
 })
 
 test_that("A nested group_count layer can be ordered properly", {
@@ -106,7 +106,23 @@ test_that("A nested group_count layer can be ordered properly", {
     )
   b_t <- build(t)
 
-  expect_equivalent(b_t[, 6], tibble(ord_layer_1 = as.integer(rep(c( 1, 2, 3), each = 3))))
+  t2 <- tplyr_table(iris, treat) %>%
+    add_layer(
+      group_count(vars(Species, grp)) %>%
+        set_order_count_method("bycount", break_ties = "asc")
+    )
+  b_t2 <- build(t2)
+
+  t3 <- tplyr_table(iris, treat) %>%
+    add_layer(
+      group_count(vars(Species, grp)) %>%
+        set_order_count_method("bycount", break_ties = "desc")
+    )
+  b_t3 <- build(t3)
+
+  expect_equal(b_t[, 6], tibble(ord_layer_1 = as.integer(rep(c( 1, 2, 3), each = 3))), ignore_attr = TRUE)
+  expect_equal(b_t2[, 6], tibble(ord_layer_1 = rep(c(25.1, 25.2, 25.3), each = 3)), ignore_attr = TRUE)
+  expect_equal(b_t3[, 6], tibble(ord_layer_1 = rep(c(25.3, 25.2, 25.1), each = 3)), ignore_attr = TRUE)
 })
 
 test_that("A group_desc layer can be ordered properly", {
@@ -121,10 +137,10 @@ test_that("A group_desc layer can be ordered properly", {
   b_t <- build(t) %>%
     arrange(ord_layer_1, ord_layer_2)
 
-  expect_equivalent(b_t[, 1], tibble(row_label1 = rep(c("4", "6", "8"), each = 2)))
-  expect_equivalent(b_t[, 2], tibble(row_label2 = rep(c("n", "Mean (SD)"), 3)))
-  expect_equivalent(b_t[, 7], tibble(ord_layer_1 = as.integer(rep(c(1, 2, 3), each = 2))))
-  expect_equivalent(b_t[, 8], tibble(ord_layer_2 = as.integer(rep(c(1, 2), 3))))
+  expect_equal(b_t[, 1], tibble(row_label1 = rep(c("4", "6", "8"), each = 2)), ignore_attr = TRUE)
+  expect_equal(b_t[, 2], tibble(row_label2 = rep(c("n", "Mean (SD)"), 3)), ignore_attr = TRUE)
+  expect_equal(b_t[, 7], tibble(ord_layer_1 = as.integer(rep(c(1, 2, 3), each = 2))), ignore_attr = TRUE)
+  expect_equal(b_t[, 8], tibble(ord_layer_2 = as.integer(rep(c(1, 2), 3))), ignore_attr = TRUE)
 
 })
 
@@ -185,12 +201,12 @@ byfactor_in <- c(Inf, 1, Inf, 1,
 
 test_that("Nested count layers are ordered properly", {
 
-  expect_equivalent(adsl_1$ord_layer_1, byvarn_out)
-  expect_equivalent(adsl_1$ord_layer_2, byvarn_in)
-  expect_equivalent(adsl_2$ord_layer_1, bycount_out)
-  expect_equivalent(adsl_2$ord_layer_2, bycount_in)
-  expect_equivalent(adsl_3$ord_layer_1, byfactor_out)
-  expect_equivalent(adsl_3$ord_layer_2, byfactor_in)
+  expect_equal(adsl_1$ord_layer_1, byvarn_out, ignore_attr = TRUE)
+  expect_equal(adsl_1$ord_layer_2, byvarn_in, ignore_attr = TRUE)
+  expect_equal(adsl_2$ord_layer_1, bycount_out, ignore_attr = TRUE)
+  expect_equal(adsl_2$ord_layer_2, bycount_in, ignore_attr = TRUE)
+  expect_equal(adsl_3$ord_layer_1, byfactor_out, ignore_attr = TRUE)
+  expect_equal(adsl_3$ord_layer_2, byfactor_in, ignore_attr = TRUE)
 
 })
 
